package com.rv.home.rv.module.ui.main.home.view;

import android.content.Context;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.base.utils.ui.datetime.selector.util.TextUtil;
import com.bumptech.glide.Glide;
import com.bumptech.glide.load.resource.bitmap.RoundedCorners;
import com.bumptech.glide.request.RequestOptions;
import com.ruiwenliu.wrapper.util.TransformationUtil2;
import com.ruiwenliu.wrapper.util.glide.GlideOptions;
import com.rv.component.utils.DisplayUtil;
import com.rv.home.R;
import com.rv.home.rv.module.ui.main.home.bean.HomeHotGoodListBean;

import java.util.List;

public class HotTravelView extends LinearLayout {

    private LinearLayout llTravelItem1, llTravelItem2, llTravelItem3, llTravelItem4;

    private List<HomeHotGoodListBean.DataBean> lists;

    private int radius = 0 ;

    public HotTravelView(Context context, AttributeSet attrs) {
        super(context, attrs);
        initView();
    }

    private void initView() {
        View view = LayoutInflater.from(getContext()).inflate(R.layout.rv_hot_travel_view, this, false);
        llTravelItem1 = view.findViewById(R.id.ll_travel_1);
        llTravelItem2 = view.findViewById(R.id.ll_travel_2);
        llTravelItem3 = view.findViewById(R.id.ll_travel_3);
        llTravelItem4 = view.findViewById(R.id.ll_travel_4);
        addView(view);
    }


    public void setData(List<HomeHotGoodListBean.DataBean> lists) {
        if (lists == null || lists.size() == 0) return;
        this.lists = lists;
        llTravelItem1.setVisibility(VISIBLE);
        setItemView(llTravelItem1, lists.get(0));
        if (lists.size() > 1) {
            llTravelItem2.setVisibility(VISIBLE);
            setItemView(llTravelItem2, lists.get(1));
        }
        if (lists.size() > 2) {
            llTravelItem3.setVisibility(VISIBLE);
            setItemView(llTravelItem3, lists.get(2));
        }
        if (lists.size() > 3) {
            llTravelItem4.setVisibility(VISIBLE);
            setItemView(llTravelItem4, lists.get(3));
        }
    }

    private void setItemView(LinearLayout linearLayout, HomeHotGoodListBean.DataBean bean) {
        setImage(bean.getIcon(),(ImageView) linearLayout.getChildAt(0));
        TextView tvContent = (TextView) linearLayout.getChildAt(1);

        if (!TextUtils.isEmpty(bean.getName())) {
            tvContent.setText(bean.getName());
        } else {
            tvContent.setText("");
        }
        TextView tvPrice = (TextView) linearLayout.getChildAt(2);
        if (!TextUtil.isEmpty(bean.getPrice())) {
            tvPrice.setText(String.format("¥%1$s%2$s", bean.getPrice(), getContext().getString(R.string.rv_one_person)));
        } else {
            tvPrice.setText("");
        }
    }

    private void setImage(String url,ImageView image){
        GlideOptions options = GlideOptions.placeholderOf(R.drawable.glide_icon_placeholder).
                error(com.ruiwenliu.wrapper.R.drawable.glide_icon_error);
        TransformationUtil2 utils = new TransformationUtil2(image);
        Glide.with(getContext())
                .asBitmap()
                .load(url)
                .apply(options)
                .apply(RequestOptions.bitmapTransform(new RoundedCorners(radius)))
                .into(utils);
    }

    public void  setRadius(int radius){
        this.radius = radius ;
    }

    public void setOnItemClickListener(OnItemClickListener listener) {

        llTravelItem1.setOnClickListener(view -> {
            if (listener != null && lists != null && lists.size() > 0) {
                listener.onItemClick(lists.get(0), 0);
            }
        });
        llTravelItem2.setOnClickListener(view -> {
            if (listener != null && lists != null && lists.size() > 1) {
                listener.onItemClick(lists.get(1), 1);
            }
        });
        llTravelItem3.setOnClickListener(view -> {
            if (listener != null && lists != null && lists.size() > 2) {
                listener.onItemClick(lists.get(2), 2);
            }
        });
        llTravelItem4.setOnClickListener(view -> {
            if (listener != null && lists != null && lists.size() > 3) {
                listener.onItemClick(lists.get(3), 0);
            }
        });
    }

    public interface OnItemClickListener {
        void onItemClick(Object o, long position);
    }
}
